==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/FinancialIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialSeriesDescriptionMetadata } from "./FinancialSeriesDescriptionMetadata";
/**
 * @hidden
 */
export let FinancialIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class FinancialIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (FinancialIndicatorDescriptionMetadata.a == null) {
                FinancialIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FinancialIndicatorDescriptionMetadata.c(FinancialIndicatorDescriptionMetadata.a);
            }
            if (a.k(FinancialIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(FinancialIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            FinancialSeriesDescriptionMetadata.c(a);
            a.item("DisplayType", "ExportedType:string:IndicatorDisplayType");
            a.item("DisplayType@names", "Line;Area;Column");
            a.item("IgnoreFirst", "Number:int");
            a.item("TrendLineType", "ExportedType:string:TrendLineType");
            a.item("TrendLineType@names", "None;LinearFit;QuadraticFit;CubicFit;QuarticFit;QuinticFit;LogarithmicFit;ExponentialFit;PowerLawFit;SimpleAverage;ExponentialAverage;ModifiedAverage;CumulativeAverage;WeightedAverage");
            a.item("TrendLineBrush", "Brush");
            a.item("ActualTrendLineBrush", "Brush");
            a.item("TrendLineThickness", "Number:double");
            a.item("TrendLinePeriod", "Number:int");
        }
        static d(a) {
            FinancialIndicatorDescriptionMetadata.b(a);
            a.ab("FinancialIndicator", FinancialIndicatorDescriptionMetadata.a);
        }
    }
    FinancialIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(FinancialIndicatorDescriptionMetadata, 'FinancialIndicatorDescriptionMetadata');
    FinancialIndicatorDescriptionMetadata.a = null;
    return FinancialIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/FinancialIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialSeriesDescriptionMetadata } from "./FinancialSeriesDescriptionMetadata";
/**
 * @hidden
 */
export let FinancialIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class FinancialIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (FinancialIndicatorDescriptionMetadata.a == null) {
                FinancialIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FinancialIndicatorDescriptionMetadata.c(FinancialIndicatorDescriptionMetadata.a);
            }
            if (a.k(FinancialIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(FinancialIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            FinancialSeriesDescriptionMetadata.c(a);
            a.item("DisplayType", "ExportedType:string:IndicatorDisplayType");
            a.item("DisplayType@names", "Line;Area;Column");
            a.item("IgnoreFirst", "Number:int");
            a.item("TrendLineType", "ExportedType:string:TrendLineType");
            a.item("TrendLineType@names", "None;LinearFit;QuadraticFit;CubicFit;QuarticFit;QuinticFit;LogarithmicFit;ExponentialFit;PowerLawFit;SimpleAverage;ExponentialAverage;ModifiedAverage;CumulativeAverage;WeightedAverage");
            a.item("TrendLineBrush", "Brush");
            a.item("ActualTrendLineBrush", "Brush");
            a.item("TrendLineThickness", "Number:double");
            a.item("TrendLineDashArray", "DoubleCollection:double");
            a.item("TrendLinePeriod", "Number:int");
        }
        static d(a) {
            FinancialIndicatorDescriptionMetadata.b(a);
            a.ad("FinancialIndicator", FinancialIndicatorDescriptionMetadata.a);
        }
    }
    FinancialIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(FinancialIndicatorDescriptionMetadata, 'FinancialIndicatorDescriptionMetadata');
    FinancialIndicatorDescriptionMetadata.a = null;
    return FinancialIndicatorDescriptionMetadata;
})();
